@@ -17,7 +17,6 @@ import os
 
 if 'DISPLAY' in os.environ:
     import gtk
-    import gobject
     import pango
     import cairo
     import glib
@@ -1483,7 +1482,7 @@ class InputBox(CommunicateWindow):
         if int(self.limittime) < 0:
             self.timeout_id = None
         else:
-            self.timeout_id = gobject.timeout_add(self.limittime, self.timeout)
+            self.timeout_id = glib.timeout_add(self.limittime, self.timeout)
         CommunicateWindow.show(self, text)
 
     def timeout(self):
@@ -1498,7 +1497,7 @@ class InputBox(CommunicateWindow):
 
     def send(self, data):
         if self.timeout_id is not None:
-            gobject.source_remove(self.timeout_id)            
+            glib.source_remove(self.timeout_id)            
         if data:
             data = unicode(data, 'utf-8')
         if data is None:
