@@ -28,7 +28,7 @@ if 'DISPLAY' in os.environ:
         except ImportError:
             pass
     import gtk
-    import gobject
+    import glib
     import pango
     import ninix.pix
 else:
@@ -301,7 +301,7 @@ class Balloon:
             print '-' * 50
             print e
             print self.script                                    
-        self.timeout_id = gobject.timeout_add(10, self.do_idle_tasks)
+        self.timeout_id = glib.timeout_add(10, self.do_idle_tasks)
 
     def clickerase(self):
         return self.data.get('clickerase', 'on') == 'on'
@@ -654,5 +654,5 @@ class Balloon:
             self.window.destroy()
             self.window = None
         if self.timeout_id:
-            gobject.source_remove(self.timeout_id)
+            glib.source_remove(self.timeout_id)
             self.timeout_id = None
