@@ -14,7 +14,7 @@
 
 # TODO: MOVE, NOCLIP, FIX, etc.
 
-import gobject
+import glib
 import gtk
 
 from ninix.dll import SAORI
@@ -74,12 +74,12 @@ class Saori(SAORI):
                     self.settings['except'] = (target, position)
             except:
                 return self.RESPONSE[400]
-            #self.timeout_id = gobject.timeout_add(self.settings['timeout'], self.do_idle_tasks)
-            self.timeout_id = gobject.timeout_add(100, self.do_idle_tasks)
+            #self.timeout_id = glib.timeout_add(self.settings['timeout'], self.do_idle_tasks)
+            self.timeout_id = glib.timeout_add(100, self.do_idle_tasks)
             return self.RESPONSE[204]
         elif argument[0] == 'STOP':
             if self.timeout_id is not None:
-                gobject.source_remove(self.timeout_id)
+                glib.source_remove(self.timeout_id)
                 self.timeout_id = None
                 self.settings = {}
             return self.RESPONSE[204]
