@@ -605,7 +605,7 @@ def read_plugin_txt(plugin_dir):
         f = open(path)
     except IOError:
         return None
-    charset = 'EUC-JP' # default
+    charset = 'UTF-8' # default
     plugin_name = startup = None
     menu_items = []
     error = None
