@@ -36,7 +36,7 @@ if 'DISPLAY' in os.environ:
         except ImportError:
             pass
     import gtk
-    import gobject
+    import glib
     import pango
     import ninix.pix
 
@@ -697,7 +697,7 @@ class Application(object):
             sakura.close()
 
     def quit(self):
-        gobject.source_remove(self.timeout_id)
+        glib.source_remove(self.timeout_id)
         self.usage_dialog.close()
         self.sstp_controler.quit() ## FIXME
         self.save_preferences()
@@ -945,7 +945,7 @@ class Application(object):
         self.usage_dialog.open(history)
 
     def set_timeout(self):
-        self.timeout_id = gobject.timeout_add(100, self.do_idle_tasks) # 100ms
+        self.timeout_id = glib.timeout_add(100, self.do_idle_tasks) # 100ms
 
     def do_idle_tasks(self):
         self.sstp_controler.handle_sstp_queue()
