@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright (C) 2003-2009 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2003-2010 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #  Copyright (C) 2003 by Shun-ichi TAHARA <jado@flowernet.gr.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
@@ -21,9 +21,8 @@ if 'DISPLAY' in os.environ:
 
 class Menu:
 
-    def __init__(self, sakura, surface):
-        self.__sakura = sakura
-        self.__surface = surface
+    def __init__(self, callback):
+        self.callback = callback
         ui_info = '''
         <ui>
           <popup name='popup'>
@@ -39,7 +38,6 @@ class Menu:
             <menu action='Options'>
             <menuitem action='Update'/>
             <menuitem action='Vanish'/>
-            <menuitem action='Reload'/>
             <menuitem action='Preferences'/>
             <menuitem action='Manager'/>
             </menu>
@@ -71,61 +69,77 @@ class Menu:
         </ui>
         '''
         self.__menu_list = { ## FIXME
-            'Portal': [('Portal', None, _('Portal sites(_P)'), None),
-                       None, 1, 1],
-            'Recommend': [('Recommend', None, _('Recommend sites(_R)'), None),
-                          None, 1, 1],
-            'Options': [('Options', None, _('Options(_F)'), None),
-                     None, 1, 1],
-            'Options/Update': [('Update', None, _('Network Update(_U)'), None,
-                             '', lambda *a: self.__sakura.network_update()),
-                            None, 1, 1],
-            'Options/Vanish': [('Vanish', None, _('Vanish(_F)'), None,
-                             '', lambda *a: self.__sakura.vanish()),
-                            None, 1, 1],
-            'Options/Reload': [('Reload', None, _('Reload(_L)'), None,
-                             '', lambda *a: self.__sakura.reload()),
-                            None, 1, 1],
-            'Options/Preferences': [('Preferences', None, _('Preferences...(_O)'), None,
-                               '', lambda *a: self.__sakura.prefs.edit_preferences()),
-                              None, 1, 1],
-            'Options/Manager': [('Manager', None, _('Ghost Manager(_M)'), None,
-                              '',
-                              lambda *a: self.__sakura.app.open_ghost_manager()),
-                             None, 1, 1],
-            'Information': [('Information', None, _('Information(_I)'), None),
-                      None, 1, 1],
-            'Information/Usage': [('Usage', None, _('Usage graph(_A)'), None,
-                            '', lambda *a: self.__sakura.app.show_usage()),
-                           None, 1, 1],
-            'Information/Version': [('Version', None, _('Version(_V)'), None,
-                              '', lambda *a: self.__sakura.about()),
-                             None, 1, 1],
-            'Close': [('Close', None, _('Close(_W)'), None,
-                      '', lambda *a: self.__sakura.close()),
-                     None, 1, 1],
+            'Portal': [
+                ('Portal', None, _('Portal sites(_P)'), None),
+                None, 1, 1],
+            'Recommend': [
+                ('Recommend', None, _('Recommend sites(_R)'), None),
+                None, 1, 1],
+            'Options': [
+                ('Options', None, _('Options(_F)'), None),
+                None, 1, 1],
+            'Options/Update': [
+                ('Update', None, _('Network Update(_U)'), None,
+                 '', lambda *a: self.callback['network_update']()),
+                None, 1, 1],
+            'Options/Vanish': [
+                ('Vanish', None, _('Vanish(_F)'), None,
+                 '', lambda *a: self.callback['vanish_sakura']()),
+                None, 1, 1],
+            'Options/Preferences': [
+                ('Preferences', None, _('Preferences...(_O)'), None,
+                 '', lambda *a: self.callback['edit_preferences']()),
+                None, 1, 1],
+            'Options/Manager': [
+                ('Manager', None, _('Ghost Manager(_M)'), None,
+                 '', lambda *a: self.callback['open_ghost_manager']()),
+                None, 1, 1],
+            'Information': [
+                ('Information', None, _('Information(_I)'), None),
+                None, 1, 1],
+            'Information/Usage': [
+                ('Usage', None, _('Usage graph(_A)'), None,
+                 '', lambda *a: self.callback['show_usage']()),
+                None, 1, 1],
+            'Information/Version': [
+                ('Version', None, _('Version(_V)'), None,
+                 '', lambda *a: self.callback['about']()),
+                None, 1, 1],
+            'Close': [
+                ('Close', None, _('Close(_W)'), None,
+                 '', lambda *a: self.callback['close_sakura']()),
+                None, 1, 1],
             'Quit': [('Quit', None, _('Quit(_Q)'), None,
-                      '', lambda *a: self.__sakura.get_callback('close all')()),
+                      '', lambda *a: self.callback['close_all']()),
                      None, 1, 1],
-            'Change': [('Change', None, _('Change(_G)'), None),
-                       None, 1, 1],
-            'Summon': [('Summon', None, _('Summon(_X)'), None),
-                       None, 1, 1],
-            'Shell': [('Shell', None, _('Shell(_S)'), None),
-                      None, 1, 1],
-            'Balloon': [('Balloon', None, _('Balloon(_B)'), None),
-                        None, 1, 1],
-            'Costume': [('Costume', None, _('Costume(_C)'), None),
-                        None, 1, 1],
-            'Stick': [('Stick', None, _('Stick(_Y)'), None,
-                       '', self.__surface.window_stick, False),
-                      None, 1, 1],
-            'Nekodorif': [('Nekodorif', None, _('Nekodorif(_N)'), None),
-                          None, 1, 1],
-            'Kinoko': [('Kinoko', None, _('Kinoko(_K)'), None),
-                       None, 1, 1],
-            'Plugin': [('Plugin', None, _('Plugin(_P)'), None),
-                       None, 1, 1],
+            'Change': [
+                ('Change', None, _('Change(_G)'), None),
+                None, 1, 1],
+            'Summon': [
+                ('Summon', None, _('Summon(_X)'), None),
+                None, 1, 1],
+            'Shell': [
+                ('Shell', None, _('Shell(_S)'), None),
+                None, 1, 1],
+            'Balloon': [
+                ('Balloon', None, _('Balloon(_B)'), None),
+                None, 1, 1],
+            'Costume': [
+                ('Costume', None, _('Costume(_C)'), None),
+                None, 1, 1],
+            'Stick': [
+                ('Stick', None, _('Stick(_Y)'), None,
+                 '', self.callback['stick_window'], False),
+                None, 1, 1],
+            'Nekodorif': [
+                ('Nekodorif', None, _('Nekodorif(_N)'), None),
+                None, 1, 1],
+            'Kinoko': [
+                ('Kinoko', None, _('Kinoko(_K)'), None),
+                None, 1, 1],
+            'Plugin': [
+                ('Plugin', None, _('Plugin(_P)'), None),
+                None, 1, 1],
             }
         self.__pixmap = None
         self.__pixmap_with_sidebar = None
@@ -153,8 +167,8 @@ class Menu:
         pixbuf = None
         if path_background and os.path.exists(path_background):
             try:
-                pixbuf = ninix.pix.create_pixbuf_from_file(path_background,
-                                                           is_pnr=0)
+                pixbuf = ninix.pix.create_pixbuf_from_file(
+                    path_background, is_pnr=False)
             except:
                 pixbuf = None
         if pixbuf is None:
@@ -169,7 +183,7 @@ class Menu:
         if path_sidebar and os.path.exists(path_sidebar):
             try:
                 pixbuf_sidebar = ninix.pix.create_pixbuf_from_file(
-                    path_sidebar, is_pnr=0)
+                    path_sidebar, is_pnr=False)
             except:
                 pixbuf_sidebar = None
         if pixbuf_sidebar:
@@ -198,16 +212,14 @@ class Menu:
                 1.0, 1.0, gtk.gdk.INTERP_BILINEAR, 255)
             self.__sidebar_width = sidebar_width
             pixmap, mask = new_pixbuf.render_pixmap_and_mask(255)
-            del pixbuf
-            del new_pixbuf
         else:
             self.__sidebar_width = 0
         self.__pixmap_with_sidebar = pixmap
         pixbuf = None
         if path_foreground and os.path.exists(path_foreground):
             try:
-                pixbuf = ninix.pix.create_pixbuf_from_file(path_foreground,
-                                                           is_pnr=0)
+                pixbuf = ninix.pix.create_pixbuf_from_file(
+                    path_foreground, is_pnr=False)
             except:
                 pixbuf = None
         if pixbuf is None:
@@ -239,9 +251,6 @@ class Menu:
                 0, 0,
                 1.0, 1.0, gtk.gdk.INTERP_BILINEAR, 255)
             pixmap, mask = new_pixbuf.render_pixmap_and_mask(255)
-            del pixbuf
-            del new_pixbuf
-            del pixbuf_sidebar
         self.__pixmap_prelight_with_sidebar = pixmap
 
     def __set_mayuna_menu(self, side):
@@ -267,11 +276,8 @@ class Menu:
                     if key != '-':
                         item = gtk.CheckMenuItem(name)
                         item.set_name('popup menu item')
-                        if state:
-                            item.set_active(True)
-                        else:
-                            item.set_active(False)
-                        item.connect('activate', self.__surface.toggle_bind,
+                        item.set_active(bool(state))
+                        item.connect('activate', self.callback['toggle_bind'],
                                      (index, key))
                     else:
                         item = gtk.SeparatorMenuItem()
@@ -320,7 +326,7 @@ class Menu:
                 name_list = self.__ui[key][0][side]
             if name_list: # caption
                 for name in name_list:
-                    caption = self.__sakura.getstring(name)
+                    caption = self.callback['getstring'](name)
                     if caption:
                         break
                 if caption:
@@ -334,7 +340,7 @@ class Menu:
                 name_list = self.__ui[key][2][side]
             if name_list: # visible
                 for name in name_list:
-                    visible = self.__sakura.getstring(name)
+                    visible = self.callback['getstring'](name)
                     if visible is not None:
                         break
                 if visible == '0':
@@ -366,10 +372,10 @@ class Menu:
             if children:
                 label = children[0]
                 style = label.style.copy()
-                map = label.get_colormap()
-                colour = map.alloc_color(self.__fontcolor['normal'])
+                cmap = label.get_colormap()
+                colour = cmap.alloc_color(self.__fontcolor['normal'])
                 style.fg[gtk.STATE_NORMAL] =  colour
-                colour = map.alloc_color(self.__fontcolor['prelight'])
+                colour = cmap.alloc_color(self.__fontcolor['prelight'])
                 style.fg[gtk.STATE_PRELIGHT] =  colour
                 label.set_style(style)
             submenu = item.get_submenu()
@@ -380,25 +386,25 @@ class Menu:
         if side > 1:
             string = 'char%d' % side
         else:
-            assert side in [0, 1]
+            assert side in [0, 1] ## FIXME
             string = ['sakura', 'kero'][side]
         string = ''.join((string, '.popupmenu.visible'))
-        if self.__sakura.getstring(string) == '0':
+        if self.callback['getstring'](string) == '0':
             return
         self.__update_ui(side)
         if side == 0:
-            portal = self.__sakura.getstring('sakura.portalsites')
+            portal = self.callback['getstring']('sakura.portalsites')
         else:
             portal = None
         self.__set_portal_menu(side, portal)
         if side > 1:
             string = 'char%d' % side
         else:
-            assert side in [0, 1]
+            assert side in [0, 1] ## FIXME
             string = ['sakura', 'kero'][side]
         string = ''.join((string, '.recommendsites'))
-        recommend = self.__sakura.getstring(string)
-        self.__set_recommend_menu(side, recommend)
+        recommend = self.callback['getstring'](string)
+        self.__set_recommend_menu(recommend)
         self.__set_ghost_menu()
         self.__set_shell_menu()
         self.__set_balloon_menu()
@@ -424,10 +430,10 @@ class Menu:
                             item.set_style(style)
                     label = item.get_children()[0]
                     style = label.style.copy()
-                    map = label.get_colormap()
-                    colour = map.alloc_color(self.__fontcolor['normal'])
+                    cmap = label.get_colormap()
+                    colour = cmap.alloc_color(self.__fontcolor['normal'])
                     style.fg[gtk.STATE_NORMAL] =  colour
-                    colour = map.alloc_color(self.__fontcolor['prelight'])
+                    colour = cmap.alloc_color(self.__fontcolor['prelight'])
                     style.fg[gtk.STATE_PRELIGHT] =  colour
                     label.set_style(style)
                     item.show()
@@ -492,7 +498,8 @@ class Menu:
                         #else:
                         #    bannar = None
                         item = gtk.MenuItem(title)
-                        item.connect('activate', self.__sakura.notify_site_selection,
+                        item.connect('activate',
+                                     self.callback['notify_site_selection'],
                                      (title, url))
                     menu.add(item)
                     item.show()
@@ -505,7 +512,7 @@ class Menu:
                 self.__set_visible('Portal', 0)
         self.__menu_list['Portal'][3] = 1 # changed
 
-    def __set_recommend_menu(self, side, recommend):
+    def __set_recommend_menu(self, recommend):
         if recommend:
             menu = gtk.Menu()
             recommend_list = recommend.split(chr(2))
@@ -526,7 +533,8 @@ class Menu:
                     #else:
                     #    bannar = None
                     item = gtk.MenuItem(title)
-                    item.connect('activate', self.__sakura.notify_site_selection,
+                    item.connect('activate',
+                                 self.callback['notify_site_selection'],
                                  (title, url))
                 menu.add(item)
                 item.show()
@@ -560,10 +568,7 @@ class Menu:
             ghost_menu.append(item)
             if len(shell_list) <= 1:
                 shell_name, value = shell_list[0]
-                if summon:
-                    item.connect('activate', callback, value)
-                else:
-                    item.connect('activate', callback, (self.__sakura, value))
+                item.connect('activate', callback, value)
                 if set_list[i]['instance'].is_running():
                     item.set_sensitive(False)
             else:
@@ -573,35 +578,30 @@ class Menu:
                 for shell_name, value in shell_list:
                     item = gtk.MenuItem(shell_name)
                     item.set_name('popup menu item')
-                    if summon:
-                        item.connect('activate', callback, value)
-                    else:
-                        item.connect('activate', callback, (self.__sakura, value))
+                    item.connect('activate', callback, value)
                     item.show()
                     if set_list[i]['instance'].is_running():
                         if summon:
                             item.set_sensitive(False)
                         else:
-                            if self.__sakura.current[1] != value[1]:
+                            set_type, i, j = self.callback['get_current_item']()
+                            if i != value[1]:
                                 item.set_sensitive(False)
-                            elif self.__sakura.current[2] == value[2]:
+                            elif j == value[2]:
                                 item.set_sensitive(False)
                     submenu.append(item)
-        if summon:
-            path = 'Summon'
-        else:
-            path = 'Change'
+        path = 'Summon' if summon else 'Change'
         menuitem = self.ui_manager.get_widget(''.join(('/popup/', path)))
         menuitem.set_submenu(ghost_menu)
         self.__menu_list[path][3] = 1
 
     def __set_ghost_menu(self):
-        ghosts = self.__sakura.app.get_ghost_list()
-        self.__update_ghost_menu(ghosts, self.__sakura.app.select_sakura, False)
-        self.__update_ghost_menu(ghosts, self.__sakura.app.start_sakura_cb, True)
+        ghosts = self.callback['get_ghost_list']()
+        self.__update_ghost_menu(ghosts, self.callback['select_sakura'], False)
+        self.__update_ghost_menu(ghosts, self.callback['start_sakura'], True)
 
     def __set_shell_menu(self):
-        set_list = self.__sakura.app.get_shell_list() ## FIXME
+        set_list = self.callback['get_shell_list']()
         shell_menu = gtk.Menu()
         for i in range(len(set_list)):
             name = set_list[i]['name']
@@ -612,8 +612,7 @@ class Menu:
             shell_list = set_list[i]['shell']
             if len(shell_list) <= 1:
                 shell_name, value = shell_list[0]
-                item.connect('activate', self.__sakura.app.select_sakura,
-                             (self.__sakura, value))
+                item.connect('activate', self.callback['select_sakura'], value)
                 ##if working:
                 ##    item.set_sensitive(False)
             else:
@@ -623,8 +622,8 @@ class Menu:
                 for shell_name, value in shell_list:
                     item = gtk.MenuItem(shell_name)
                     item.set_name('popup menu item')
-                    item.connect('activate', self.__sakura.app.select_sakura,
-                                 (self.__sakura, value))
+                    item.connect('activate', self.callback['select_sakura'],
+                                 value)
                     item.show()
                     ##if working: ## FIXME
                     ##    item.set_sensitive(False)
@@ -634,14 +633,14 @@ class Menu:
         self.__menu_list['Shell'][3] = 1
 
     def __set_balloon_menu(self):
-        balloon_list = self.__sakura.app.get_balloon_list()
+        balloon_list = self.callback['get_balloon_list']()
         balloon_menu = gtk.Menu()
         group = None
-        name_own = self.__sakura.get_own_balloon_name()
+        name_own = self.callback['get_own_balloon_name']()
         if name_own is not None:
             item = group = gtk.RadioMenuItem(group, name_own)
             item.set_name('popup menu item')
-            hid = item.connect('activate', self.__sakura.select_balloon,
+            hid = item.connect('activate', self.callback['select_balloon'],
                                name_own)
             item.show()
             balloon_menu.append(item)
@@ -652,10 +651,11 @@ class Menu:
             name = balloon_list[i]['name']
             item = group = gtk.RadioMenuItem(group, name)
             item.set_name('popup menu item')
-            hid = item.connect('activate', self.__sakura.select_balloon, name)
+            hid = item.connect('activate',
+                               self.callback['select_balloon'], name)
             item.show()
             balloon_menu.append(item)
-            if name == self.__sakura.get_current_balloon_name():
+            if name == self.callback['get_current_balloon_name']():
                 item.handler_block(hid)
                 item.activate()
                 item.handler_unblock(hid)
@@ -664,7 +664,7 @@ class Menu:
         self.__menu_list['Balloon'][3] = 1
 
     def __set_plugin_menu(self):
-        plugin_list = self.__sakura.app.get_plugin_list()
+        plugin_list = self.callback['get_plugin_list']()
         plugin_menu = gtk.Menu()
         for i in range(len(plugin_list)):
             name = plugin_list[i]['name']
@@ -675,7 +675,7 @@ class Menu:
             item_list = plugin_list[i]['items']
             if len(item_list) <= 1:
                 label, value = item_list[0]
-                item.connect('activate', self.__sakura.app.select_plugin, value)
+                item.connect('activate', self.callback['select_plugin'], value)
                 ##if working:
                 ##    item.set_sensitive(False)
             else:
@@ -685,7 +685,7 @@ class Menu:
                 for label, value in item_list:
                     item = gtk.MenuItem(label)
                     item.set_name('popup menu item')
-                    item.connect('activate', self.__sakura.app.select_plugin,
+                    item.connect('activate', self.callback['select_plugin'],
                                  value)
                     item.show()
                     ##if working:
@@ -696,7 +696,7 @@ class Menu:
         self.__menu_list['Plugin'][3] = 1
 
     def __set_nekodorif_menu(self):
-        nekodorif_list = self.__sakura.app.get_nekodorif_list()
+        nekodorif_list = self.callback['get_nekodorif_list']()
         nekodorif_menu = gtk.Menu()
         for i in range(len(nekodorif_list)):
             name = nekodorif_list[i]['name']
@@ -704,8 +704,8 @@ class Menu:
             item.set_name('popup menu item')
             item.show()
             nekodorif_menu.append(item)
-            item.connect('activate', self.__sakura.app.select_nekodorif,
-                         (self.__sakura, nekodorif_list[i]['dir']))
+            item.connect('activate', self.callback['select_nekodorif'],
+                         nekodorif_list[i]['dir'])
             ##if working:
             ##    item.set_sensitive(False)
         menuitem = self.ui_manager.get_widget(
@@ -714,7 +714,7 @@ class Menu:
         self.__menu_list['Nekodorif'][3] = 1
 
     def __set_kinoko_menu(self):
-        kinoko_list = self.__sakura.app.get_kinoko_list()
+        kinoko_list = self.callback['get_kinoko_list']()
         kinoko_menu = gtk.Menu()
         for i in range(len(kinoko_list)):
             name = kinoko_list[i]['title']
@@ -722,8 +722,8 @@ class Menu:
             item.set_name('popup menu item')
             item.show()
             kinoko_menu.append(item)
-            item.connect('activate', self.__sakura.app.select_kinoko,
-                         (self.__sakura, kinoko_list[i]))
+            item.connect('activate', self.callback['select_kinoko'],
+                         kinoko_list[i])
             ##if working:
             ##    item.set_sensitive(False)
         menuitem = self.ui_manager.get_widget(''.join(('/popup/', 'Kinoko')))
@@ -732,10 +732,7 @@ class Menu:
 
     def get_stick(self):
         item =  self.ui_manager.get_widget(''.join(('/popup/', 'Stick')))
-        if item and item.get_active():
-            return 1
-        else:
-            return 0
+        return 1 if item and item.get_active() else 0
 
 
 def test():
