@@ -51,7 +51,7 @@ import random
 
 if 'DISPLAY' in os.environ:
     import gtk
-    import gobject
+    import glib
     import ninix.pix
 
 import ninix.home
@@ -167,7 +167,7 @@ class Nekoninni:
         self.katochan = None
         self.launch_katochan(self.katochan_list[0])
         self.__running = 1
-        gobject.timeout_add(50, self.do_idle_tasks) # 50ms
+        glib.timeout_add(50, self.do_idle_tasks) # 50ms
         return 1
 
     def do_idle_tasks(self):
