@@ -16,6 +16,30 @@
 import os
 import signal
 import sys
+import socket
+
+
+def send_script(sender, script, if_ghost=None):
+    try:
+        port = int(os.environ.get("NINIX_SSTP_PORT", "none"))
+    except ValueError:
+        raise SystemExit, 'NINIX_SSTP_PORT not found.'
+    address = ("", port)
+    sstp = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    try:
+        sstp.connect(address)
+    except socket.error:
+        raise SystemExit, 'cannot connect to the SSTP server.'
+    message = ''.join(('SEND SSTP/1.4\r\n',
+                       'Sender: ', sender, '\r\n',
+                       'Script: ', script, '\r\n',
+                       'Charset: UTF-8\r\n'))
+    if if_ghost is not None:
+        message = ''.join((message, 'IfGhost: ', if_ghost, '\r\n'))
+    message = ''.join((message, '\r\n'))
+    sstp.send(message)
+    sstp.recv(1024)
+    sstp.close()
 
 
 class PluginControler:
