@@ -26,7 +26,7 @@ import StringIO
 
 if 'DISPLAY' in os.environ:
     import gtk ## FIXME
-    import gobject
+    import glib
 
 # For some reasons gst parses sys.argv on import. This is a workaround.
 # (See https://bugzilla.gnome.org/show_bug.cgi?id=549879 .)
@@ -662,7 +662,7 @@ class Sakura:
         def proc(self=self):
             self.vanished_count += 1
             self.ghost_time = 0
-            gobject.idle_add(self.callback['vanish_sakura'], self)
+            glib.idle_add(self.callback['vanish_sakura'], self)
         self.enqueue_event('OnVanishSelected', proc=proc)
         self.vanished = 1 ## FIXME
 
@@ -858,6 +858,8 @@ class Sakura:
         self.set_balloon(desc, balloon)
         self.balloon.set_balloon_default()
         print 'balloon', item
+        path = '' ## FIXME
+        self.notify_event('OnBalloonChange', item, path)
 
     def surface_bootup(self):
         for side in [0, 1]:
@@ -1050,7 +1052,7 @@ class Sakura:
         self.restart()
         self.start_time = time.time()
         self.notify_start(init, vanished, ghost_changed, name, surface_dir)
-        gobject.timeout_add(10, self.do_idle_tasks) # 10ms
+        glib.timeout_add(10, self.do_idle_tasks) # 10ms
 
     def restart(self):
         self.load_history()
@@ -1488,7 +1490,10 @@ class Sakura:
 
     def __yen_and(self, args):
         if self.name2codepoint is not None:
-            text = unichr(self.name2codepoint.get(args[0]))
+            try:
+                text = unichr(self.name2codepoint.get(args[0]))
+            except:
+                text = None
         else:
             text = None
         if text is None:
