@@ -16,7 +16,7 @@ import re
 import sys
 import random
 
-import gobject
+import glib
 
 def print_error(message):
     sys.stderr.write(''.join((message, '\n')))
@@ -58,13 +58,13 @@ class Controler:
 
     def set_animation_quality(self, quality, window):
         if self.timeout_id is not None:
-            gobject.source_remove(self.timeout_id)
+            glib.source_remove(self.timeout_id)
         if quality is None:
             quality = 1.0
         step = 0.033 / quality ## FIXME
         self.frame['step'] = step
         if self.timeout_id is not None:
-            self.timeout_id = gobject.timeout_add(int(step * 1000.0), self.update, window)
+            self.timeout_id = glib.timeout_add(int(step * 1000.0), self.update, window)
 
     def set_inactive(self, flag, window):
         self.__inactive = bool(flag)
@@ -86,7 +86,7 @@ class Controler:
         if last_actor is not None and last_actor.exclusive and \
            last_actor.terminate_flag and self.exclusive_actor is None: # XXX
             self.invoke_restart(window)
-        self.idle_id = gobject.timeout_add(10, self.update_frame, window) # XXX
+        self.idle_id = glib.timeout_add(10, self.update_frame, window) # XXX
         return False
 
     def get_actor_next(self, window):
@@ -106,7 +106,7 @@ class Controler:
             return False
         if not self.__inactive:
             window.update()
-        self.timeout_id = gobject.timeout_add(int(self.frame['step'] * 1000), self.update, window)
+        self.timeout_id = glib.timeout_add(int(self.frame['step'] * 1000), self.update, window)
         return False
 
     def lock_exclusive(self, window, actor):
@@ -235,16 +235,16 @@ class Controler:
     def start(self, window):
         self.invoke_runonce(window)
         self.invoke_always(window)
-        self.timeout_id = gobject.timeout_add(int(self.frame['step'] * 1000),
-                                              self.update, window)
+        self.timeout_id = glib.timeout_add(int(self.frame['step'] * 1000),
+                                           self.update, window)
 
     def terminate(self, window):
         self.terminate_flag = 1
         if self.timeout_id is not None:
-            gobject.source_remove(self.timeout_id)
+            glib.source_remove(self.timeout_id)
             self.timeout_id = None
         if self.idle_id is not None:
-            gobject.source_remove(self.idle_id)
+            glib.source_remove(self.idle_id)
             self.idle_id = None
         if self.base_id in self.seriko:
             for actor in self.seriko[self.base_id]:
