@@ -2,7 +2,7 @@
 #
 #  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
 #  Copyright (C) 2002, 2003 by MATSUMURA Namihiko <nie@counterghost.net>
-#  Copyright (C) 2002-2009 by Shyouzou Sugitani <shy@users.sourceforge.jp>
+#  Copyright (C) 2002-2010 by Shyouzou Sugitani <shy@users.sourceforge.jp>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -25,8 +25,8 @@ from sstplib import AsynchronousSSTPServer, BaseSSTPRequestHandler
 
 class SSTPServer(AsynchronousSSTPServer):
 
-    def __init__(self, address, app):
-        self.__app = app
+    def __init__(self, address, callback):
+        self.callback = callback
         AsynchronousSSTPServer.__init__(self, address, SSTPRequestHandler)
         self.request_handler = None
 
@@ -57,30 +57,11 @@ class SSTPServer(AsynchronousSSTPServer):
     def close(self):
         self.socket.close()
 
-    def get_current_sakura(self):
-        return self.__app.get_current_sakura()
-
-    def if_ghost(self, ifghost):
-        return self.__app.if_ghost(ifghost)
-
-    def get_ghost_names(self):
-        return self.__app.get_ghost_names()
-
-    def check_request_queue(self, sender):
-        return self.__app.check_request_queue(sender)
-
-    def enqueue_script_if_ghost(
-        self, if_ghost, script, sender, handle,
-        address, show_sstp_marker, use_translator, entry_db):
-        self.__app.enqueue_script_if_ghost(
-            if_ghost, script, sender, handle,
-            address, show_sstp_marker, use_translator, entry_db)
 
 class SSTPRequestHandler(BaseSSTPRequestHandler):
 
     def handle(self):
-        sakura = self.server.get_current_sakura()
-        if not sakura.cantalk:
+        if not self.server.callback['get_sakura_cantalk']():
             self.error = self.version = None
             if not self.parse_request(self.rfile.readline()):
                 return
@@ -157,8 +138,7 @@ class SSTPRequestHandler(BaseSSTPRequestHandler):
         event = self.get_event()
         if event is None:
             return
-        sakura = self.server.get_current_sakura()
-        script = sakura.get_event_response(*event)
+        script = self.server.callback['get_event_response'](*event)
         if script and self.check_script(script):
             return
         if version == 1.0:
@@ -184,7 +164,7 @@ class SSTPRequestHandler(BaseSSTPRequestHandler):
             address = self.client_address
         self.send_response(200) # OK
         show_sstp_marker, use_translator = self.get_options()
-        self.server.enqueue_script_if_ghost(
+        self.server.callback['enqueue_script_if_ghost'](
             if_ghost, script, sender, handle,
             address, show_sstp_marker, use_translator, entry_db)
 
@@ -196,17 +176,16 @@ class SSTPRequestHandler(BaseSSTPRequestHandler):
         if entry_db is None or entry_db.is_empty():
             self.send_response(200) # OK
             show_sstp_marker, use_translator = self.get_options()
-            sakura = self.server.get_current_sakura()
-            sakura.enqueue_script(script, sender, handle, address,
-                                  show_sstp_marker, use_translator)
+            self.server.callback['enqueue_script'](
+                script, sender, handle, address,
+                show_sstp_marker, use_translator)
         elif self.server.request_handler:
             self.send_response(409) # Conflict
         else:
             show_sstp_marker, use_translator = self.get_options()
-            sakura = self.server.get_current_sakura()
-            sakura.enqueue_script(script, sender, handle, address,
-                                  show_sstp_marker, use_translator,
-                                  entry_db, self.server)
+            self.server.callback['enqueue_script'](
+                script, sender, handle, address,
+                show_sstp_marker, use_translator, entry_db, self.server)
             self.server.request_handler = self # keep alive
 
     PROHIBITED_TAGS = [r'\j', r'\-', r'\+', r'\_+', r'\!']
@@ -255,11 +234,11 @@ class SSTPRequestHandler(BaseSSTPRequestHandler):
                     continue
                 script = line[7:].strip()
                 if current: # NOTIFY
-                    ghost = self.ghost_names()
+                    ghost = self.server.callback['get_ghost_name']()
                     if ghost == if_ghost:
                         return script, if_ghost
                 else: # SEND
-                    if self.server.if_ghost(if_ghost):
+                    if self.server.callback['if_ghost'](if_ghost):
                         return script, if_ghost
                 if default is None:
                     default = script, if_ghost
@@ -352,10 +331,6 @@ class SSTPRequestHandler(BaseSSTPRequestHandler):
             result = host ==  '127.0.0.1'
         return result
 
-    def ghost_names(self):
-        sakura = self.server.get_current_sakura()
-        return '%s,%s' % (sakura.get_selfname(), sakura.get_keroname())
-
     # EXECUTE
     def do_EXECUTE_1_0(self):
         self.handle_command()
@@ -390,7 +365,7 @@ class SSTPRequestHandler(BaseSSTPRequestHandler):
             return
         elif command == 'getname':
             self.send_response(200)
-            name = self.ghost_names()
+            name = self.server.callback['get_ghost_name']()
             self.wfile.write(''.join((name.encode('utf-8', 'ignore'), '\r\n')))
             self.wfile.write('Charset: UTF-8\r\n')
         elif command == 'getversion':
@@ -398,25 +373,19 @@ class SSTPRequestHandler(BaseSSTPRequestHandler):
             self.wfile.write('ninix-aya %s\r\n' % ninix.version.VERSION)
         elif command == 'quiet':
             self.send_response(200)
-            sakura = self.server.get_current_sakura()
-            sakura.keep_silence(True)
+            self.server.callback['keep_silence'](True)
         elif command == 'restore':
             self.send_response(200)
-            sakura = self.server.get_current_sakura()
-            sakura.keep_silence(False)
-        elif command == 'reload':
-            self.send_response(200)
-            sakura = self.server.get_current_sakura()
-            sakura.app.reload() ## FIXME
+            self.server.callback['keep_silence'](False)
         elif command == 'getnames':
             self.send_response(200)
-            for name in self.server.get_ghost_names():
+            for name in self.server.callback['get_ghost_names']():
                 self.wfile.write(
                     ''.join((name.encode('utf-8', 'ignore'), '\r\n')))
             self.wfile.write('Charset: UTF-8\r\n')
         elif command == 'checkqueue':
             self.send_response(200)
-            count, total = self.server.check_request_queue(sender)
+            count, total = self.server.callback['check_request_queue'](sender)
             self.wfile.write(''.join((count, '\r\n')))
             self.wfile.write(''.join((total, '\r\n')))
         else:
@@ -432,7 +401,7 @@ class SSTPRequestHandler(BaseSSTPRequestHandler):
             return None
         return unicode(command, charset, 'replace').lower()
 
-    def do_COMMUNICATE_1_1(self): ## FIXME
+    def do_COMMUNICATE_1_1(self):
         if not self.check_decoder():
             return
         sender = self.get_sender()
@@ -442,8 +411,8 @@ class SSTPRequestHandler(BaseSSTPRequestHandler):
         if sentence is None:
             return
         self.send_response(200) # OK
-        sakura = self.server.get_current_sakura()
-        sakura.enqueue_event('OnCommunicate', sender, sentence)
+        self.server.callback['enqueue_event'](
+            'OnCommunicate', sender, sentence)
         return
 
     def get_sentence(self):
